==> qtjambi-qt3danimation-jre8-5.15.3-sources.jar: io/qt/qt3d/animation/QCallbackMapping.java <==
package io.qt.qt3d.animation;


/**
 * <p>Allows to map the channels within the clip onto an invocation of a callback object</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3danimation-qcallbackmapping.html">Qt3DAnimation::QCallbackMapping</a></p>
 */
public class QCallbackMapping extends io.qt.qt3d.animation.QAbstractChannelMapping
{
    @io.qt.QtPropertyMember(enabled=false)
    private Object __rcCallback = null;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCallbackMapping.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qcallbackmapping.html#channelName-prop">Qt3DAnimation::QCallbackMapping::channelNameChanged(QString)</a></p>
     */
    @io.qt.QtPropertyNotify(name="channelName")
    public final Signal1<java.lang.String> channelNameChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QCallbackMapping(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QCallbackMapping() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QCallbackMapping(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCallbackMapping instance, io.qt.qt3d.core.QNode parent);
    
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAnimationCallback callback(){
        return callback_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAnimationCallback callback_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qcallbackmapping.html#channelName-prop">Qt3DAnimation::QCallbackMapping::channelName()const</a></p>
     */
    @io.qt.QtPropertyReader(name="channelName")
    @io.qt.QtUninvokable
    public final java.lang.String channelName(){
        return channelName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String channelName_native_constfct(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #setCallback(int, io.qt.qt3d.animation.QAnimationCallback, io.qt.qt3d.animation.QAnimationCallback.Flags)}.</p>
     */
    @io.qt.QtUninvokable
    public final void setCallback(int type, io.qt.qt3d.animation.QAnimationCallback callback, io.qt.qt3d.animation.QAnimationCallback.Flag ... flags){
        setCallback(type, callback, new io.qt.qt3d.animation.QAnimationCallback.Flags(flags));
    }
    
    /**
     * <p>Overloaded function for {@link #setCallback(int, io.qt.qt3d.animation.QAnimationCallback, io.qt.qt3d.animation.QAnimationCallback.Flags)}
     *  with <code>flags = new io.qt.qt3d.animation.QAnimationCallback.Flags(0)</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void setCallback(int type, io.qt.qt3d.animation.QAnimationCallback callback) {
        setCallback(type, callback, new io.qt.qt3d.animation.QAnimationCallback.Flags(0));
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qcallbackmapping.html#setCallback">Qt3DAnimation::QCallbackMapping::setCallback(int,Qt3DAnimation::QAnimationCallback*,QAnimationCallback::Flags)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setCallback(int type, io.qt.qt3d.animation.QAnimationCallback callback, io.qt.qt3d.animation.QAnimationCallback.Flags flags){
        setCallback_native_int_Qt3DAnimation_QAnimationCallback_ptr_QFlags_Qt3DAnimation_QAnimationCallback_Flag_(QtJambi_LibraryUtilities.internal.nativeId(this), type, QtJambi_LibraryUtilities.internal.checkedNativeId(callback), flags.value());
        __rcCallback = callback;
    }
    
    @io.qt.QtUninvokable
    private native void setCallback_native_int_Qt3DAnimation_QAnimationCallback_ptr_QFlags_Qt3DAnimation_QAnimationCallback_Flag_(long __this__nativeId, int type, long callback, int flags);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qcallbackmapping.html#channelName-prop">Qt3DAnimation::QCallbackMapping::setChannelName(QString)</a></p>
     */
    @io.qt.QtPropertyWriter(name="channelName")
    public final void setChannelName(java.lang.String channelName){
        setChannelName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), channelName);
    }
    
    private native void setChannelName_native_cref_QString(long __this__nativeId, java.lang.String channelName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QCallbackMapping(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QCallbackMapping(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QCallbackMapping instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3danimation-jre8-6.2.1-sources.jar: io/qt/qt3d/animation/QCallbackMapping.java <==
package io.qt.qt3d.animation;


/**
 * <p>Allows to map the channels within the clip onto an invocation of a callback object</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3danimation-qcallbackmapping.html">Qt3DAnimation::QCallbackMapping</a></p>
 */
public class QCallbackMapping extends io.qt.qt3d.animation.QAbstractChannelMapping
{
    @io.qt.QtPropertyMember(enabled=false)
    private Object __rcCallback = null;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCallbackMapping.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qcallbackmapping.html#channelName-prop">Qt3DAnimation::QCallbackMapping::channelNameChanged(QString)</a></p>
     */
    @io.qt.QtPropertyNotify(name="channelName")
    public final Signal1<java.lang.String> channelNameChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QCallbackMapping(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QCallbackMapping() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QCallbackMapping(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCallbackMapping instance, io.qt.qt3d.core.QNode parent);
    
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAnimationCallback callback(){
        return callback_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAnimationCallback callback_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qcallbackmapping.html#channelName-prop">Qt3DAnimation::QCallbackMapping::channelName()const</a></p>
     */
    @io.qt.QtPropertyReader(name="channelName")
    @io.qt.QtUninvokable
    public final java.lang.String channelName(){
        return channelName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String channelName_native_constfct(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #setCallback(int, io.qt.qt3d.animation.QAnimationCallback, io.qt.qt3d.animation.QAnimationCallback.Flags)}.</p>
     */
    @io.qt.QtUninvokable
    public final void setCallback(int type, io.qt.qt3d.animation.QAnimationCallback callback, io.qt.qt3d.animation.QAnimationCallback.Flag ... flags){
        setCallback(type, callback, new io.qt.qt3d.animation.QAnimationCallback.Flags(flags));
    }
    
    /**
     * <p>Overloaded function for {@link #setCallback(int, io.qt.qt3d.animation.QAnimationCallback, io.qt.qt3d.animation.QAnimationCallback.Flags)}
     *  with <code>flags = new io.qt.qt3d.animation.QAnimationCallback.Flags(0)</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void setCallback(int type, io.qt.qt3d.animation.QAnimationCallback callback) {
        setCallback(type, callback, new io.qt.qt3d.animation.QAnimationCallback.Flags(0));
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qcallbackmapping.html#setCallback">Qt3DAnimation::QCallbackMapping::setCallback(int,Qt3DAnimation::QAnimationCallback*,QAnimationCallback::Flags)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setCallback(int type, io.qt.qt3d.animation.QAnimationCallback callback, io.qt.qt3d.animation.QAnimationCallback.Flags flags){
        setCallback_native_int_Qt3DAnimation_QAnimationCallback_ptr_QFlags_Qt3DAnimation_QAnimationCallback_Flag_(QtJambi_LibraryUtilities.internal.nativeId(this), type, QtJambi_LibraryUtilities.internal.checkedNativeId(callback), flags.value());
        __rcCallback = callback;
    }
    
    @io.qt.QtUninvokable
    private native void setCallback_native_int_Qt3DAnimation_QAnimationCallback_ptr_QFlags_Qt3DAnimation_QAnimationCallback_Flag_(long __this__nativeId, int type, long callback, int flags);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qcallbackmapping.html#channelName-prop">Qt3DAnimation::QCallbackMapping::setChannelName(QString)</a></p>
     */
    @io.qt.QtPropertyWriter(name="channelName")
    public final void setChannelName(java.lang.String channelName){
        setChannelName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), channelName);
    }
    
    private native void setChannelName_native_cref_QString(long __this__nativeId, java.lang.String channelName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QCallbackMapping(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QCallbackMapping(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QCallbackMapping instance, QDeclarativeConstructor constructor);
    
}
